from __future__ import annotations
from staticsite.feature import Feature
from staticsite.theme import PageFilter
import logging

log = logging.getLogger("pages")


class PagesFeature(Feature):
    """
    Expand a 'pages' metadata containing a page filter into a list of pages.
    """
    RUN_AFTER = ["autogenerated_pages"]

    def __init__(self, *args, **kw):
        super().__init__(*args, **kw)
        self.site.tracked_metadata.add("pages")
        self.site.features["rst"].yaml_tags.add("pages")

    def finalize(self):
        # Expand pages expressions
        for page in self.site.pages_by_metadata["pages"]:
            pages = page.meta["pages"]
            # Skip pages that already have a populated pages list
            if not isinstance(pages, dict):
                continue

            # Replace the dict with the expanded list of pages
            f = PageFilter(self.site, **pages)
            page.meta["pages"] = f.filter(self.site.pages.values())


FEATURES = {
    "pages": PagesFeature,
}
